==> ah-formbuilder-1.0.46.tgz: package/es/components/toolbar/field-forms/utils/FieldRenderer.js <==
var _jsxFileName = "/home/ayesha/Project/formbuilder/src/components/toolbar/field-forms/utils/FieldRenderer.js";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import _ from 'lodash';
import { FIELD_TYPES } from '../../../../utils/Globals';
import Checkbox from '../../../../utils/checkboxs/Checkbox';
import SearchableSelect from '../../../../utils/selects/SearchableSelect';
import TextInput from '../../../../utils/inputs/TextInput';
import { connect } from "react-redux";

var FieldRenderer = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(FieldRenderer, _React$Component);

  function FieldRenderer() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;

    _defineProperty(_assertThisInitialized(_this), "renderLocalFields", function (field, key) {
      var _this$props = _this.props,
          locals = _this$props.locals,
          addLanguageSelect = _this$props.addLanguageSelect,
          currentLang = _this$props.currentLang;

      if (field && locals && locals.length && field.isTranslatable) {
        return locals.reduce(function (arr, local) {
          if (local.key === addLanguageSelect) {
            var newField = _.cloneDeep(field);

            newField.configs.label = {
              en: field.configs.label[currentLang] + " " + local.name,
              ar: field.configs.label[currentLang] + " " + local.name
            };
            newField.configs.required = false;
            newField.configs.autoFocus = false;
            arr.push(_this.renderField(newField, key + "_" + local.key, true));
          }

          return arr;
        }, []);
      }
    });

    _defineProperty(_assertThisInitialized(_this), "renderField", function (field, key) {
      var _field$configs, _field$configs2, _field$configs3;

      var _this$props2 = _this.props,
          fieldConfigs = _this$props2.fieldConfigs,
          locals = _this$props2.locals,
          handleDataChange = _this$props2.handleDataChange,
          rest = _objectWithoutPropertiesLoose(_this$props2, ["fieldConfigs", "locals", "handleDataChange"]);

      var error = false;
      if (field.error && key in rest.errors) error = rest.errors[key];

      switch (field.type) {
        case FIELD_TYPES.CHECKBOX:
          return !(field == null ? void 0 : (_field$configs = field.configs) == null ? void 0 : _field$configs.hidden) && /*#__PURE__*/React.createElement("div", {
            key: key,
            className: "ahfb-mb-4",
            __self: _assertThisInitialized(_this),
            __source: {
              fileName: _jsxFileName,
              lineNumber: 44,
              columnNumber: 11
            }
          }, /*#__PURE__*/React.createElement(Checkbox, _extends({}, field.configs, {
            label: field.configs.label[_this.props.currentLang],
            checked: rest[key],
            value: rest[key],
            handleChange: function handleChange(val) {
              return handleDataChange(val, key);
            },
            error: error,
            __self: _assertThisInitialized(_this),
            __source: {
              fileName: _jsxFileName,
              lineNumber: 45,
              columnNumber: 13
            }
          })));

        case FIELD_TYPES.SEARCHABLE_SELECT:
          var formattedData = [];

          _.map(field.configs.options, function (row) {
            var formattedObj = {};
            formattedObj.value = row.value;
            formattedObj.label = row.label[_this.props.currentLang];
            formattedData.push(formattedObj);
          });

          return !(field == null ? void 0 : (_field$configs2 = field.configs) == null ? void 0 : _field$configs2.hidden) && /*#__PURE__*/React.createElement("div", {
            key: key,
            className: "ahfb-mb-4",
            __self: _assertThisInitialized(_this),
            __source: {
              fileName: _jsxFileName,
              lineNumber: 64,
              columnNumber: 11
            }
          }, /*#__PURE__*/React.createElement(SearchableSelect, _extends({}, field.configs, {
            label: field.configs.label[_this.props.currentLang],
            value: rest[key],
            handleChange: function handleChange(e) {
              return handleDataChange(e.target.value, key);
            },
            error: error,
            options: formattedData,
            __self: _assertThisInitialized(_this),
            __source: {
              fileName: _jsxFileName,
              lineNumber: 65,
              columnNumber: 13
            }
          })));

        case FIELD_TYPES.TEXT:
          return !(field == null ? void 0 : (_field$configs3 = field.configs) == null ? void 0 : _field$configs3.hidden) && /*#__PURE__*/React.createElement(React.Fragment, {
            key: key,
            __self: _assertThisInitialized(_this),
            __source: {
              fileName: _jsxFileName,
              lineNumber: 77,
              columnNumber: 11
            }
          }, /*#__PURE__*/React.createElement("div", {
            className: "ahfb-mb-4",
            __self: _assertThisInitialized(_this),
            __source: {
              fileName: _jsxFileName,
              lineNumber: 78,
              columnNumber: 13
            }
          }, /*#__PURE__*/React.createElement(TextInput, _extends({}, field.configs, {
            label: field.configs.label[_this.props.currentLang],
            value: rest[key],
            handleChange: function handleChange(e) {
              return handleDataChange(e.target.value, key);
            },
            error: error,
            __self: _assertThisInitialized(_this),
            __source: {
              fileName: _jsxFileName,
              lineNumber: 79,
              columnNumber: 15
            }
          }))));
      }
    });

    return _this;
  }

  var _proto = FieldRenderer.prototype;

  _proto.render = function render() {
    var _this2 = this;

    var fieldConfigs = this.props.fieldConfigs;
    return /*#__PURE__*/React.createElement("div", {
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 97,
        columnNumber: 7
      }
    }, fieldConfigs && Object.keys(fieldConfigs).map(function (key) {
      return /*#__PURE__*/React.createElement(React.Fragment, {
        key: key,
        __self: _this2,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 100,
          columnNumber: 13
        }
      }, _this2.renderField(fieldConfigs[key], key), fieldConfigs[key].isTranslatable && _this2.renderLocalFields(fieldConfigs[key], key));
    }));
  };

  return FieldRenderer;
}(React.Component);

var mapStateToProps = function mapStateToProps(state) {
  return {
    locals: state.form.locals,
    addLanguageSelect: state.form.addLanguageSelect,
    currentLang: state.form.currentLang
  };
};

export default connect(mapStateToProps, null)(FieldRenderer);

==> ah-formbuilder-1.0.61.tgz: package/es/components/toolbar/field-forms/utils/FieldRenderer.js <==
var _excluded = ["fieldConfigs", "locals", "handleDataChange"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import _ from 'lodash';
import { FIELD_TYPES } from '../../../../utils/Globals';
import Checkbox from '../../../../utils/checkboxs/Checkbox';
import SearchableSelect from '../../../../utils/selects/SearchableSelect';
import TextInput from '../../../../utils/inputs/TextInput';
import { connect } from "react-redux";

var FieldRenderer = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(FieldRenderer, _React$Component);

  function FieldRenderer() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;

    _defineProperty(_assertThisInitialized(_this), "renderLocalFields", function (field, key) {
      var _this$props = _this.props,
          locals = _this$props.locals,
          addLanguageSelect = _this$props.addLanguageSelect,
          currentLang = _this$props.currentLang;

      if (field && locals && locals.length && field.isTranslatable) {
        return locals.reduce(function (arr, local) {
          if (local.key === addLanguageSelect) {
            var newField = _.cloneDeep(field);

            newField.configs.label = {
              en: field.configs.label[currentLang] + " " + local.name,
              ar: field.configs.label[currentLang] + " " + local.name
            };
            newField.configs.required = false;
            newField.configs.autoFocus = false;
            arr.push(_this.renderField(newField, key + "_" + local.key, true));
          }

          return arr;
        }, []);
      }
    });

    _defineProperty(_assertThisInitialized(_this), "renderField", function (field, key) {
      var _field$configs, _field$configs2, _field$configs3;

      var _this$props2 = _this.props,
          fieldConfigs = _this$props2.fieldConfigs,
          locals = _this$props2.locals,
          handleDataChange = _this$props2.handleDataChange,
          rest = _objectWithoutPropertiesLoose(_this$props2, _excluded);

      var error = false;
      if (field.error && key in rest.errors) error = rest.errors[key];

      switch (field.type) {
        case FIELD_TYPES.CHECKBOX:
          return !(field != null && (_field$configs = field.configs) != null && _field$configs.hidden) && /*#__PURE__*/React.createElement("div", {
            key: key,
            className: "ahfb-mb-4"
          }, /*#__PURE__*/React.createElement(Checkbox, _extends({}, field.configs, {
            label: field.configs.label[_this.props.currentLang],
            checked: rest[key],
            value: rest[key],
            handleChange: function handleChange(val) {
              return handleDataChange(val, key);
            },
            error: error
          })));

        case FIELD_TYPES.SEARCHABLE_SELECT:
          var formattedData = [];

          _.map(field.configs.options, function (row) {
            var formattedObj = {};
            formattedObj.value = row.value;
            formattedObj.label = row.label[_this.props.currentLang];
            formattedData.push(formattedObj);
          });

          return !(field != null && (_field$configs2 = field.configs) != null && _field$configs2.hidden) && /*#__PURE__*/React.createElement("div", {
            key: key,
            className: "ahfb-mb-4"
          }, /*#__PURE__*/React.createElement(SearchableSelect, _extends({}, field.configs, {
            label: field.configs.label[_this.props.currentLang],
            value: rest[key],
            handleChange: function handleChange(e) {
              return handleDataChange(e.target.value, key);
            },
            error: error,
            options: formattedData
          })));

        case FIELD_TYPES.TEXT:
          return !(field != null && (_field$configs3 = field.configs) != null && _field$configs3.hidden) && /*#__PURE__*/React.createElement(React.Fragment, {
            key: key
          }, /*#__PURE__*/React.createElement("div", {
            className: "ahfb-mb-4"
          }, /*#__PURE__*/React.createElement(TextInput, _extends({}, field.configs, {
            label: field.configs.label[_this.props.currentLang],
            value: rest[key],
            handleChange: function handleChange(e) {
              return handleDataChange(e.target.value, key);
            },
            error: error
          }))));
      }
    });

    return _this;
  }

  var _proto = FieldRenderer.prototype;

  _proto.render = function render() {
    var _this2 = this;

    var fieldConfigs = this.props.fieldConfigs;
    return /*#__PURE__*/React.createElement("div", null, fieldConfigs && Object.keys(fieldConfigs).map(function (key) {
      return /*#__PURE__*/React.createElement(React.Fragment, {
        key: key
      }, _this2.renderField(fieldConfigs[key], key), fieldConfigs[key].isTranslatable && _this2.renderLocalFields(fieldConfigs[key], key));
    }));
  };

  return FieldRenderer;
}(React.Component);

var mapStateToProps = function mapStateToProps(state) {
  return {
    locals: state.form.locals,
    addLanguageSelect: state.form.addLanguageSelect,
    currentLang: state.form.currentLang
  };
};

export default connect(mapStateToProps, null)(FieldRenderer);
